==> oer-0.0.2-20190820.092159-13-sources.jar: com/xdja/pki/itsca/oer/app/data/KekBuilder.java <==
package com.xdja.pki.itsca.oer.app.data;

import com.xdja.pki.gmssl.crypto.sdf.SdfCryptoType;
import com.xdja.pki.gmssl.crypto.utils.GMSSLSM2EncryptUtils;
import com.xdja.pki.itsca.oer.asn1.*;
import com.xdja.pki.itsca.oer.utils.ASN1SM2Cipher;
import com.xdja.pki.itsca.oer.utils.BCUtils;
import com.xdja.pki.itsca.oer.utils.X509Utils;
import org.bouncycastle.util.BigIntegers;

import java.security.PublicKey;

/**
 * @ClassName KekBuilder
 */
public class KekBuilder {
    public static EciesEncryptedKey build(EccPoint eccPoint, byte[] key) throws Exception {
        EciesEncryptedKey kek = new EciesEncryptedKey();
        byte[] x = eccPoint.getUncompressed().getX().getString();
        byte[] y = eccPoint.getUncompressed().getY().getString();
        PublicKey publicKey = X509Utils.convertSM2PublicKey(x, y);

//        byte[] cipher = BCUtils.sm2EncryptASN1ByBC(publicKey, key);
        byte[] cipher = GMSSLSM2EncryptUtils.encryptASN1BySdf(SdfCryptoType.YUNHSM, publicKey, key, 0, key.length);
        ASN1SM2Cipher asn1SM2Cipher = ASN1SM2Cipher.getInstance(cipher);
        kek.setEccCurve(new EccCurve(EccCurve.SGD_SM2));
        EccPoint v = new EccPoint();
        Uncompressed vu = new Uncompressed();
        vu.setX(BCUtils.change32Length(asn1SM2Cipher.getxCoordinate()));
        vu.setY(BCUtils.change32Length(asn1SM2Cipher.getyCoordinate()));
        v.setUncompressed(vu);
        kek.setV(v);
        kek.setC(asn1SM2Cipher.getCipherText());
        kek.setT(asn1SM2Cipher.getHash());
        return kek;
    }
}

==> oer-0.0.2-20190823.092113-22-sources.jar: com/xdja/pki/itsca/oer/app/data/KekBuilder.java <==
package com.xdja.pki.itsca.oer.app.data;

import com.xdja.pki.gmssl.crypto.sdf.SdfCryptoType;
import com.xdja.pki.gmssl.crypto.utils.GMSSLSM2EncryptUtils;
import com.xdja.pki.itsca.oer.asn1.*;
import com.xdja.pki.itsca.oer.utils.ASN1SM2Cipher;
import com.xdja.pki.itsca.oer.utils.BCUtils;
import com.xdja.pki.itsca.oer.utils.ByteArrayUtils;
import com.xdja.pki.itsca.oer.utils.X509Utils;
import org.bouncycastle.util.BigIntegers;

import java.security.PublicKey;

/**
 * @ClassName KekBuilder
 */
public class KekBuilder {
    public static EciesEncryptedKey build(EccPoint eccPoint, byte[] key) throws Exception {
        byte[] x = eccPoint.getUncompressed().getX().getString();
        byte[] y = eccPoint.getUncompressed().getY().getString();
        PublicKey publicKey = X509Utils.convertSM2PublicKey(x, y);
        return build(publicKey, key);
    }

    public static EciesEncryptedKey build(PublicKey publicKey, byte[] key) throws Exception {
        EciesEncryptedKey kek = new EciesEncryptedKey();
//        byte[] cipher = BCUtils.sm2EncryptASN1ByBC(publicKey, key);
        byte[] cipher = GMSSLSM2EncryptUtils.encryptASN1BySdf(SdfCryptoType.YUNHSM, publicKey, key, 0, key.length);
        ASN1SM2Cipher asn1SM2Cipher = ASN1SM2Cipher.getInstance(cipher);
        kek.setEccCurve(new EccCurve(EccCurve.SGD_SM2));
        EccPoint v = new EccPoint();
        Uncompressed vu = new Uncompressed();
        vu.setX(ByteArrayUtils.changeByteArrayLength(asn1SM2Cipher.getxCoordinate()));
        vu.setY(ByteArrayUtils.changeByteArrayLength(asn1SM2Cipher.getyCoordinate()));
        v.setUncompressed(vu);
        kek.setV(v);
        kek.setC(asn1SM2Cipher.getCipherText());
        kek.setT(asn1SM2Cipher.getHash());
        return kek;
    }
}
